from prettyqt.qt import QtWidgets


class StyleFactory(QtWidgets.QStyleFactory):
    pass
